import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_evaluate_route.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

final String _randomInfinitive = 'infinitive';

void main() {
  testWidgets('Test the content of a 6/6 score', (WidgetTester tester) async {
    await tester.pumpWidget(ChangeNotifierProvider(
      create: (BuildContext context) {
        var model = VerbTestModel();
        model.initialise(_randomIndicative, _randomPronouns, 'fr',
            _randomInfinitive, 'translation');
        int i = 0;
        _randomIndicative.forEach((element) {
          model.add(element, i++);
        });
        return model;
      },
      child: VerbIndicativeEvaluateRoute(),
    ));
    Finder titleFinder = find.text('Vervoeging ${_randomInfinitive}');
    expect(titleFinder, findsOneWidget);
    Finder scoreFinder = find.text('6/6');
    expect(scoreFinder, findsOneWidget);
    _randomIndicative.forEach((element) {
      final Finder indicativeFinder = find.text(element);
      expect(indicativeFinder, findsOneWidget);
    });
  });

  testWidgets('Test the content of a 5/6 score', (WidgetTester tester) async {
    await tester.pumpWidget(ChangeNotifierProvider(
      create: (BuildContext context) {
        var model = VerbTestModel();
        model.initialise(_randomIndicative, _randomPronouns, 'fr',
            _randomInfinitive, 'translation');
        int i = 0;
        _randomIndicative.forEach((element) {
          model.add(element, i++);
        });
        //tamper with 3rd person singular
        model.add('wrong', 2);
        return model;
      },
      child: VerbIndicativeEvaluateRoute(),
    ));
    Finder titleFinder = find.text('Vervoeging ${_randomInfinitive}');
    expect(titleFinder, findsOneWidget);
    Finder scoreFinder = find.text('5/6');
    expect(scoreFinder, findsOneWidget);
    int i = 0;
    _randomIndicative.forEach((element) {
      final Finder indicativeFinder = find.text(element);
      expect(indicativeFinder, i == 2 ? findsNothing : findsOneWidget);
      i++;
    });
  });
}
